@@ -440,7 +440,9 @@ $$R = B^P \mod M$$"""
         problem.testcases_sample.append(TestCase(input="4\n5", output="9"))
         if translations:
             for tran_lang in translations:
-                problem.translations[tran_lang] = Problem(name=problem.name)
+                tran_lang = tran_lang.strip()
+                if tran_lang:
+                    problem.translations[tran_lang] = Problem(name=problem.name)
 
         ProblemService.save(problem, folder, overwrite=overwrite, lang=lang)
 
